==> 1.0.20.tar.gz: lib/modules/local_cart/local_cart_model.dart <==
List<LocalCart> localCartListFromJson(dynamic str) =>
    List<LocalCart>.from(str.map((x) => LocalCart.fromJson(x)));

class LocalCart {
  late final String packName;
  late final String packId;
  late final String packImage;
  late final String packSku;
  late final String setId;
  late final int quantity;
  late final int piece;
  late final int setPrice;
  late final int price;
  late final String variant;
  late final double igst;
  late final double cgst;
  late final double sgst;
  late final String variantValue;
  late final bool isOutofstock;
  late final String sTypename;

  LocalCart(
      {required this.packName,
      required this.packId,
      required this.packImage,
      required this.packSku,
      required this.setId,
      required this.quantity,
      required this.piece,
      required this.setPrice,
      required this.price,
      required this.variant,
      required this.igst,
      required this.cgst,
      required this.sgst,
      required this.variantValue,
      required this.isOutofstock,
      required this.sTypename});

  LocalCart.fromJson(Map<String, dynamic> json) {
    packName = json['packName'];
    packId = json['packId'];
    packImage = json['packImage'];
    packSku = json['packSku'];
    setId = json['setId'];
    quantity = json['quantity'];
    piece = json['piece'];
    setPrice = json['setPrice'];
    price = json['price'];
    variant = json['variant'];
    igst = json['igst'];
    cgst = json['cgst'];
    sgst = json['sgst'];
    variantValue = json['variantValue'];
    isOutofstock = json['isOutofstock'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['packName'] = this.packName;
    data['packId'] = this.packId;
    data['packImage'] = this.packImage;
    data['packSku'] = this.packSku;
    data['setId'] = this.setId;
    data['quantity'] = this.quantity;
    data['piece'] = this.piece;
    data['setPrice'] = this.setPrice;
    data['price'] = this.price;
    data['variant'] = this.variant;
    data['igst'] = this.igst;
    data['cgst'] = this.cgst;
    data['sgst'] = this.sgst;
    data['variantValue'] = this.variantValue;
    data['isOutofstock'] = this.isOutofstock;
    data['__typename'] = this.sTypename;
    return data;
  }
}

==> 1.0.128.tar.gz: lib/modules/local_cart/local_cart_model.dart <==
List<LocalCart> localCartListFromJson(dynamic str) =>
    List<LocalCart>.from(str.map((x) => LocalCart.fromJson(x)));

class LocalCart {
  late final String packName;
  late final String packId;
  late final String packImage;
  late final String packSku;
  late final String setId;
  late final int quantity;
  late final int piece;
  late final int setPrice;
  late final int price;
  late final String variant;
  late final double igst;
  late final double cgst;
  late final double sgst;
  late final String variantValue;
  late final bool isOutofstock;
  late final String sTypename;

  LocalCart(
      {required this.packName,
      required this.packId,
      required this.packImage,
      required this.packSku,
      required this.setId,
      required this.quantity,
      required this.piece,
      required this.setPrice,
      required this.price,
      required this.variant,
      required this.igst,
      required this.cgst,
      required this.sgst,
      required this.variantValue,
      required this.isOutofstock,
      required this.sTypename});

  LocalCart.fromJson(Map<String, dynamic> json) {
    packName = json['packName'];
    packId = json['packId'];
    packImage = json['packImage'];
    packSku = json['packSku'];
    setId = json['setId'];
    quantity = json['quantity'];
    piece = json['piece'];
    setPrice = json['setPrice'];
    price = json['price'];
    variant = json['variant'];
    igst = json['igst'].toDouble();
    cgst = json['cgst'].toDouble();
    sgst = json['sgst'].toDouble();
    variantValue = json['variantValue'];
    isOutofstock = json['isOutofstock'];
    sTypename = json['__typename'];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = new Map<String, dynamic>();
    data['packName'] = this.packName;
    data['packId'] = this.packId;
    data['packImage'] = this.packImage;
    data['packSku'] = this.packSku;
    data['setId'] = this.setId;
    data['quantity'] = this.quantity;
    data['piece'] = this.piece;
    data['setPrice'] = this.setPrice;
    data['price'] = this.price;
    data['variant'] = this.variant;
    data['igst'] = this.igst;
    data['cgst'] = this.cgst;
    data['sgst'] = this.sgst;
    data['variantValue'] = this.variantValue;
    data['isOutofstock'] = this.isOutofstock;
    data['__typename'] = this.sTypename;
    return data;
  }
}
